package com.taobao.api.request;

import com.taobao.api.internal.util.RequestCheckUtils;
import java.util.Map;
import java.util.HashMap;

import com.taobao.api.ApiRuleException;
import com.taobao.api.BaseTaobaoRequest;
import com.taobao.api.FileItem;
import com.taobao.api.TaobaoUploadRequest;
import com.taobao.api.internal.util.TaobaoHashMap;

import com.taobao.api.response.TmallExchangeRefuseResponse;

/**
 * TOP API: tmall.exchange.refuse request
 * 
 * @author top auto create
 * @since 1.0, 2018.08.09
 */
public class TmallExchangeRefuseRequest extends BaseTaobaoRequest<TmallExchangeRefuseResponse> implements TaobaoUploadRequest<TmallExchangeRefuseResponse> {

	
	

	/** 
	* 换货单号ID
	 */
	private Long disputeId;

	/** 
	* 返回字段。目前支持dispute_id, bizorder_id, modified, status
	 */
	private String fields;

	/** 
	* 拒绝换货申请时的留言
	 */
	private String leaveMessage;

	/** 
	* 凭证图片
	 */
	private FileItem leaveMessagePics;

	/** 
	* 换货原因对应ID
	 */
	private Long sellerRefuseReasonId;

	public void setDisputeId(Long disputeId) {
		this.disputeId = disputeId;
	}

	public Long getDisputeId() {
		return this.disputeId;
	}

	public void setFields(String fields) {
		this.fields = fields;
	}

	public String getFields() {
		return this.fields;
	}

	public void setLeaveMessage(String leaveMessage) {
		this.leaveMessage = leaveMessage;
	}

	public String getLeaveMessage() {
		return this.leaveMessage;
	}

	public void setLeaveMessagePics(FileItem leaveMessagePics) {
		this.leaveMessagePics = leaveMessagePics;
	}

	public FileItem getLeaveMessagePics() {
		return this.leaveMessagePics;
	}

	public void setSellerRefuseReasonId(Long sellerRefuseReasonId) {
		this.sellerRefuseReasonId = sellerRefuseReasonId;
	}

	public Long getSellerRefuseReasonId() {
		return this.sellerRefuseReasonId;
	}

	public String getApiMethodName() {
		return "tmall.exchange.refuse";
	}

	public Map<String, String> getTextParams() {
		TaobaoHashMap txtParams = new TaobaoHashMap();
		txtParams.put("dispute_id", this.disputeId);
		txtParams.put("fields", this.fields);
		txtParams.put("leave_message", this.leaveMessage);
		txtParams.put("seller_refuse_reason_id", this.sellerRefuseReasonId);
		if(this.udfParams != null) {
			txtParams.putAll(this.udfParams);
		}
		return txtParams;
	}

	public Class<TmallExchangeRefuseResponse> getResponseClass() {
		return TmallExchangeRefuseResponse.class;
	}

	public void check() throws ApiRuleException {
		
		RequestCheckUtils.checkNotEmpty(disputeId, "disputeId");
		RequestCheckUtils.checkNotEmpty(fields, "fields");
		RequestCheckUtils.checkMaxListSize(fields, 20, "fields");
		RequestCheckUtils.checkNotEmpty(sellerRefuseReasonId, "sellerRefuseReasonId");
	}

	public Map<String, FileItem> getFileParams() {
		Map<String, FileItem> params = new HashMap<String, FileItem>();
		params.put("leave_message_pics", this.leaveMessagePics);
		return params;
	}
	
	

}